Index: src/serialize.h |
diff --git a/src/serialize.h b/src/serialize.h |
index 264bd46f460015a392047afaeb9a478bcf0054a7..30eb364892ce0728e06245f69aa276108b9b7082 100644 |
--- a/src/serialize.h |
+++ b/src/serialize.h |
@@ -912,14 +912,16 @@ class SnapshotData : public SerializedData { |
private: |
bool IsSane(); |
// The data header consists of int-sized entries: |
// [0] version hash |
// [1] number of reservation size entries |
// [2] payload length |
+ // ... reservations |
+ // ... serialized payload |
static const int kCheckSumOffset = 0; |
static const int kReservationsOffset = 1; |
static const int kPayloadLengthOffset = 2; |
- static const int kHeaderSize = (kPayloadLengthOffset + 1) * kIntSize; |
+ static const int kHeaderSize = (kPayloadLengthOffset + 1) * sizeof(uint32_t); |
jochen (gone - plz use gerrit)
2015/02/10 09:00:22
if it's supposed to be pointer aligned, why not si
|
}; |
@@ -957,7 +959,7 @@ class SerializedCodeData : public SerializedData { |
uint32_t SourceHash(String* source) const { return source->length(); } |
// The data header consists of int-sized entries: |
// [0] version hash |
// [1] source hash |
// [2] cpu features |
@@ -966,6 +968,11 @@ class SerializedCodeData : public SerializedData { |
// [5] number of code stub keys |
// [6] number of reservation size entries |
// [7] payload length |
+ // [8] payload checksum part 1 |
+ // [9] payload checksum part 2 |
+ // ... reservations |
+ // ... code stub keys |
+ // ... serialized payload |
static const int kVersionHashOffset = 0; |
static const int kSourceHashOffset = 1; |
static const int kCpuFeaturesOffset = 2; |
@@ -976,8 +983,7 @@ class SerializedCodeData : public SerializedData { |
static const int kPayloadLengthOffset = 7; |
static const int kChecksum1Offset = 8; |
static const int kChecksum2Offset = 9; |
- static const int kHeaderSize = |
- POINTER_SIZE_ALIGN((kChecksum2Offset + 1) * kIntSize); |
+ static const int kHeaderSize = (kChecksum2Offset + 1) * sizeof(uint32_t); |
}; |
} } // namespace v8::internal |
@@ -912,14 +912,16 @@ class SnapshotData : public SerializedData { |
private: |
bool IsSane(); |
- // The data header consists of int-sized entries: |
+ // The data header consists of uint32_t-sized entries: |
// [0] version hash |
// [1] number of reservation size entries |
@@ -957,7 +959,7 @@ class SerializedCodeData : public SerializedData { |
uint32_t SourceHash(String* source) const { return source->length(); } |
- // The data header consists of int-sized entries: |
+ // The data header consists of uint32_t-sized entries: |
// [0] version hash |
// [1] source hash |